*******************************************
*
* 2010 CCES Big Five and Tea Party Analysis
*
*******************************************

use "`localpath'sourcedata\YaleCCES2010_TeaParty.dta", clear
set more 1

****************************
*
* RECODE DEMOGRAPHIC AND POLITICAL VARIABLES
*
****************************
gen weight=v102
label var weight "Team weight"

*State
tab v206, gen(state_)
 *drop CA indicator
drop state_5

*Race
tab v211, gen(race)
gen r_white=race1
gen r_black=race2
gen r_hispanic=race3
gen r_otherrace=race4+race5+race6+race7+race8
label var r_white "Race: White (1=yes)"
label var r_black "Race: Black (1=yes)"
label var r_hispanic "Race: Hispanic (1=yes)"
label var r_otherrace "Race: Other Race (1=yes)"

*Gender
gen gender=v208-1
label var gender "Female (1=yes)"

*Age
gen age=2010-v207
gen age2=(age^2)/100
label var age "Age (Years)"
label var age2 "Age-squared/100"

*Family Income
gen income=v246
replace income=15 if income>15
gen incomemis = (income>14)
label var incomemis "Income Missing"
label var income "Income (1=<10k; 14=>150k; 15=RF/Skipped)"
tab income, gen(incomeD)
drop incomeD5
label var incomeD1 "Income: <$10k"
label var incomeD2 "Income: $10-<$15k"
label var incomeD3 "Income: $15-<$20k"
label var incomeD4 "Income: $20-<$25k"
label var incomeD6 "Income: $30-<$40k"
label var incomeD7 "Income: $40-<$50k"
label var incomeD8 "Income: $50-<$60k"
label var incomeD9 "Income: $60-<$70k"
label var incomeD10 "Income: $70-<$80k"
label var incomeD11 "Income: $80-<$100k"
label var incomeD12 "Income: $100-<$120k"
label var incomeD13 "Income: $120-<$150k"
label var incomeD14 "Income: $150k+"
label var incomeD15 "Income: Prefer not to say"

*Education
gen educ=v213
label var educ "Education (1=No HS; 6=Post-grad)"
tab educ, gen(educD)
drop educD3
label var educD1 "Education: No HS"
label var educD2 "Education: High School"
label var educD4 "Education: 2-year college"
label var educD5 "Education: 4-year college"
label var educD6 "Education: Post-graduate"

* Marital Status
gen married=(v214==1)|(v214==6)
label var married "Married/Domestic Partnership (1=yes)"

*Religious Attendance
recode v217 (1=6) (2=5) (3=4) (4=3) (5=2) (6=1) (*=.), gen(religatt)
label var religatt "Religious Attendance (1-6)"

*PID
recode v212d (1=3) (2=2) (3=1) (4 8=0) (5=-1) (6=-2) (7=-3) (*=.), gen(pid7)
label var pid7 "Party ID (-3=Str. Rep.; 0=Ind./Not sure; 3=Str. Dem.)"
tab pid7, gen(d_pid_)
drop d_pid_4
label var d_pid_1 "Party: Strong Republican"
label var d_pid_2 "Party: Weak Republican"
label var d_pid_3 "Party: Lean Republican"
label var d_pid_5 "Party: Lean Democrat"
label var d_pid_6 "Party: Weak Democrat"
label var d_pid_7 "Party: Strong Democrat"

*Strength of PID
gen pidstr7=abs(pid7)
label var pidstr7 "Strength PID (0=Indep/not sure, 3=Str. ID)"

*Ideology
recode cc334a (1=3) (2=2) (3=1) (4 8=0) (5=-1) (6=-2) (7=-3) (*=.), gen(ideol)
label var ideol "Ideology (-3=very cons.; 0=moderate/not sure; +3=very lib.)"
tab ideol, gen(d_ideol_)
drop d_ideol_4
label var d_ideol_1 "Ideology: Very conservative"
label var d_ideol_2 "Ideology: Conservative"
label var d_ideol_3 "Ideology: Somewhat conservative"
label var d_ideol_5 "Ideology: Somewhat liberal"
label var d_ideol_6 "Ideology: Liberal"
label var d_ideol_7 "Ideology: Very liberal"

*Str. Ideology
gen ideolstr=abs(ideol)
label var ideolstr "Str. Ideology (0=moderate/not sure; +3=str. ideol)"

*Interest in Politics
recode v244 (1=4) (2=3) (3=2) (4=1) (*=.), gen(interest)
label var interest "Interest in News & Public Affairs (1=Hardly at all; 4=Most of the time)"

*2008 Turnout
recode cc316 (1 2 3=0) (4=1) (*=.), gen(turnout08)
label var turnout08 "Voted in 2008 (1=yes)"

*2008 Vote Choice
recode cc317 (1=1) (2=-1) (3 5=0) (*=.), gen(presvote08)
label var presvote08 "Pres. Vote Choice in 2008 (-1=McCain; 0=Someone else/don't recall; 1=Obama)"

* Taxes v. spending
recode cc415r (101/. = .), gen(cut_spending)
replace cut_spending=cut_spending/100

****************************
*
* TIPI (CONSTRUCT BIG FIVE ITEMS)
*
****************************
*personality - extraverted
gen b_p_extraverted=yalpsy001
recode b_p_extraverted (8=.) (9=.)

*personality - critical 
gen b_p_critical=yalpsy002
recode b_p_critical (8=.) (9=.)

*personality - dependable
gen b_p_dependable=yalpsy003
recode b_p_dependable (8=.) (9=.)

*personality - anxious
gen b_p_anxious=yalpsy004
recode b_p_anxious (8=.) (9=.)

*personality - open to new experiences
gen b_p_open=yalpsy005
recode b_p_open (8=.) (9=.)

*personality - reserved
gen b_p_reserved=yalpsy006
recode b_p_reserved (8=.) (9=.)

*personality - sympathetic
gen b_p_sympathetic=yalpsy007
recode b_p_sympathetic (8=.) (9=.)

*personality - disorganized
gen b_p_disorganized=yalpsy008
recode b_p_disorganized (8=.) (9=.)

*personality - calm
gen b_p_calm=yalpsy009
recode b_p_calm (8=.) (9=.)

*personality - conventional
gen b_p_conventional=yalpsy010
recode b_p_conventional (8=.) (9=.)

***Items range from 0 to 1 -- higher values mean more of the trait

*Big Five - Extraversion
recode b_p_reserved (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_reserved_R)
gen BF_extraversion = (((b_p_extraverted + b_p_reserved_R)/2)-1)/6
label var BF_extraversion "Extraversion (0-1)"

*Big Five - Agreeableness
recode b_p_critical (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_critical_R)
gen BF_agreeableness = (((b_p_sympathetic + b_p_critical_R)/2)-1)/6
label var BF_agreeableness "Agreeableness (0-1)"

*Big Five - Conscientiousness
recode b_p_disorganized (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_disorganized_R)
gen BF_conscientiousness = (((b_p_dependable + b_p_disorganized_R)/2)-1)/6
label var BF_conscientiousness "Conscientiousness (0-1)"

*Big Five - Emotional Stability
recode b_p_anxious (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_anxious_R)
gen BF_stability = (((b_p_calm + b_p_anxious_R)/2)-1)/6
label var BF_stability "Stability (0-1)"

*Big Five - Openness to Experiences
recode b_p_conventional (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_conventional_R)
gen BF_openness = (((b_p_open + b_p_conventional_R)/2)-1)/6
label var BF_openness "Openness (0-1)"

foreach i in BF_extraver BF_agree BF_conscien BF_stabil BF_openn {
egen std_`i'=std(`i')
replace `i'=std_`i'
}
label var BF_extraver "Extraversion (standardized)"
label var BF_agree "Agreeableness (standardized)"
label var BF_conscien "Conscientiousness (standardized)"
label var BF_stabil "Stability (standardized)"
label var BF_openn "Openness (standardized)"

****************************
*
* OUTCOME: TEA PARTY FAVORABILITY
*
****************************
recode cc424 (1=2) (2=1) (3 6 7 8=0) (4=-1) (5=-2) (*=.), gen(favteapty)
label var favteapty "Favorability toward Tea Party (-2=very neg.; 0=neutral/no opinion/DK; +2=very pos.)"

recode cc424 (1=2) (2=1) (3 7=0) (4=-1) (5=-2) (*=.), gen(favteapty2)
label var favteapty2 "Favorability toward Tea Party (-2=very neg.; 0=neutral/no opinion; +2=very pos.)"

recode cc424 (1=2) (2=1) (3=0) (4=-1) (5=-2) (*=.), gen(favteapty3)
label var favteapty3 "Favorability toward Tea Party (-2=very neg.; 0=neutral; +2=very pos.)"

****************************
*
* ANALYSIS (TABLE 10)
*
****************************
*Set Sample
reg favteapty gender r_black r_hispanic r_other age age2 incomeD* educD* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness d_ideol_*
gen insample = e(sample)

*Summary Statistics (not reported)
sum favteapty favteapty2 favteapty3 BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness gender r_black r_hispanic r_other r_white age age2 educ income incomemis ideol if insample==1 [aw=weight]

*First, Base Model (includes education and income categories), then Controlling for Ideology categories
qui ologit favteapty3 gender r_black r_hispanic r_other age age2 incomeD* educD* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* if insample==1 [aw=weight], cluster(v206)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness gender r_black r_hispanic r_other age age2 using "logs\Table10.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) replace 

qui ologit favteapty3 gender r_black r_hispanic r_other age age2 incomeD* educD* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness d_ideol_* state* if insample==1 [aw=weight], cluster(v206)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness gender r_black r_hispanic r_other age age2 d_ideol_* using "logs\Table10.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) append 


